@@ -20,6 +20,9 @@ class WindowsButtonsWidget(TitlebarButtonsWidget):
 
         self.__styleInit()
 
+        self.__window = self._base_widget.window()
+        self.__window.installEventFilter(self)
+
     def __styleInit(self):
         close_button_style = self._closeBtn.styleSheet() + f'''
                              QPushButton:hover 
@@ -38,4 +41,12 @@ class WindowsButtonsWidget(TitlebarButtonsWidget):
     def event(self, e):
         if e.type() == 100:
             self.__styleInit()
-        return super().event(e)
\ No newline at end of file
+        return super().event(e)
+
+    def eventFilter(self, obj, e):
+        if e.type() == 105:
+            if self.__window.isMaximized():
+                self._maximizeBtn.setText('🗗')
+            else:
+                self._maximizeBtn.setText('🗖')
+        return super().eventFilter(obj, e)
